/*
======================================================================
vecmat.h

Ernie Wright  07 Jan 04

Definitions and prototypes for vector and matrix operations.

----------------------------------------------------------------------
Copyright (c) 2007 by Ernie Wright

This file is part of the Linux version of Almagest Stars, which is
made available under the terms of version 2 of the GNU General Public
License (GPL) as published by the Free Software Foundation.  A copy of
the license should have been supplied to you in a file named COPYING
that accompanied this file.  A copy is also at http://www.gnu.org.
----------------------------------------------------------------------
====================================================================== */

#ifndef VECMAT_H
#define VECMAT_H


typedef double Vector[ 3 ];
typedef double Matrix3[ 3 ][ 3 ];
typedef double Matrix4[ 4 ][ 4 ];


#define HEADING 0
#define PITCH   1
#define BANK    2


void initm3( Matrix3 m,
   double a1, double b1, double c1,
   double a2, double b2, double c2,
   double a3, double b3, double c3 );
void identity3( Matrix3 m );
void copym3( Matrix3 to, Matrix3 from );

void copyv( Vector to, Vector from );
double dot( Vector a, Vector b );
double vlenSquared( Vector a );
double vlen( Vector a );
void scalev( Vector a, double s );
void setvlen( Vector a, double d );
void normalize( Vector a );

double ry_heading( double a );
double rx_pitch( double a );
double range( double v, double r );
void sphere_vec( double lon, double lat, Vector a );
void vec_sphere( Vector a, double *lon, double *lat );

void transform( Vector a, Matrix3 m, Vector b );
void matmul3( Matrix3 a, Matrix3 b, Matrix3 c );
void mulrot3( Matrix3 M, double angle, int axis );
void transpose3( Matrix3 m );

void transform4( Vector a, Matrix4 m, Vector b );
void matmul4( Matrix4 a, Matrix4 b, Matrix4 c );
void scalem3( Matrix3 a, double s );
void scalem4( Matrix4 a, double s );
double det2( double a, double b, double c, double d );
double det3( Matrix3 m );
double det4( Matrix4 m );
void adjoint3( Matrix3 m, Matrix3 adj );
void adjoint4( Matrix4 m, Matrix4 adj );
void inverse3( Matrix3 m, Matrix3 inv );
void inverse4( Matrix4 m, Matrix4 inv );

#endif
