/*
======================================================================
view.h

Ernie Wright  10 Jul 06

Structures and prototypes for the view

   viewInit()        set some View fields
   viewUpdate()      calculate pradius and transformation matrices
   viewToPixel()     convert from camera to pixel (x, y)
   pixelToEcl()      convert from (x, y) to lon-lat
   pixelToEclEq()    convert from (x, y) to both lon-lat and ra-dec

Also declared here but actually defined in cats.c:

   initConViewDefaults()
   getConViewDefaults()

----------------------------------------------------------------------
Copyright (c) 2007 by Ernie Wright

This file is part of the Linux version of Almagest Stars, which is
made available under the terms of version 2 of the GNU General Public
License (GPL) as published by the Free Software Foundation.  A copy of
the license should have been supplied to you in a file named COPYING
that accompanied this file.  A copy is also at http://www.gnu.org.
----------------------------------------------------------------------
====================================================================== */

#ifndef VIEW_H
#define VIEW_H

typedef struct st_View {
   double      lon;                 /* view direction longitude, radians */
   double      lat;                 /* latitude, radians */
   double      bank;                /* bank angle, radians */
   double      zoom;                /* zoom (eye distance in window heights) */
   Matrix4     Mv;                  /* view transformation matrix */
   Matrix4     iMv;                 /* inverse view matrix */
   int         width;               /* window width, pixels */
   int         height;              /* window height, pixels */
   double      pradius;             /* half-degree radius, pixels */
} View;


typedef struct st_ConViewDefaults {
   float        errLon;             /* systematic errors in longitude */
   float        errLat;             /*  and latitude, radians */
   float        lon;                /* default viewing parameters */
   float        lat;                /*  for this constellation */
   float        bank;
   float        zoom;
} ConViewDefaults;


void viewInit( View *view, double lon, double lat, double bank, double zoom );
void viewUpdate( View *view );
int  viewToPixel( View *view, Vector pos, float *x, float *y );
void pixelToEcl( View *view, int x, int y, float *lon, float *lat );
void pixelToEclEq( View *view, int x, int y, double jd,
      float *lon, float *lat, float *ra, float *dec );
void initConViewDefaults( ConViewDefaults cv[] );
void getConViewDefaults( ConViewDefaults *cv, int i );

#endif
